@@ -67,7 +67,7 @@ ggRGB <- function(img, r = 3, g = 2, b = 1, scale, maxpixels = 500000, stretch =
     
     ## TODO: handle single value rasters (e.g. masks)
     
-	# RGB processing originally forked from raster:::plotRGB
+	# RGB processing originally forked from raster::plotRGB
 	# Author: Robert J. Hijmans 
 	# Version 0.9
 	# Licence GPL v3
@@ -164,7 +164,7 @@ ggRGB <- function(img, r = 3, g = 2, b = 1, scale, maxpixels = 500000, stretch =
 			dz <- matrix(z, nrow=nrow(rr), ncol=ncol(rr), byrow = TRUE)  
 			p <- annotation_raster(raster = dz, xmin = exe[1], xmax = exe[2], ymin = exe[3], ymax = exe[4], interpolate = FALSE)
 			if(!ggLayer) {
-				p <- ggplot(df, aes(x = x,y = y)) + p
+				p <- ggplot() + p + geom_blank(data = df, aes(x = x,y = y))
 			}
 		} else {
 			p <- geom_raster(data = df_raster, aes(x = x, y = y, fill = fill), alpha = alpha)  
